#include "AT_StoppingPowerDataPSTAR.h"

PSTAR_data_for_material_struct PSTAR_Water = {
  Water_Liquid,
  PARTICLE_PROTON_NUMBER,
  {
		  { 1.000E-03 , 1.769E+02 },
		  { 1.500E-03 , 1.984E+02 },
		  { 2.000E-03 , 2.184E+02 },
		  { 2.500E-03 , 2.370E+02 },
		  { 3.000E-03 , 2.544E+02 },
		  { 4.000E-03 , 2.864E+02 },
		  { 5.000E-03 , 3.153E+02 },
		  { 6.000E-03 , 3.420E+02 },
		  { 7.000E-03 , 3.667E+02 },
		  { 8.000E-03 , 3.900E+02 },
		  { 9.000E-03 , 4.120E+02 },
		  { 1.000E-02 , 4.329E+02 },
		  { 1.250E-02 , 4.745E+02 },
		  { 1.500E-02 , 5.110E+02 },
		  { 1.750E-02 , 5.437E+02 },
		  { 2.000E-02 , 5.733E+02 },
		  { 2.250E-02 , 6.001E+02 },
		  { 2.500E-02 , 6.245E+02 },
		  { 2.750E-02 , 6.467E+02 },
		  { 3.000E-02 , 6.671E+02 },
		  { 3.500E-02 , 7.028E+02 },
		  { 4.000E-02 , 7.324E+02 },
		  { 4.500E-02 , 7.569E+02 },
		  { 5.000E-02 , 7.768E+02 },
		  { 5.500E-02 , 7.927E+02 },
		  { 6.000E-02 , 8.050E+02 },
		  { 6.500E-02 , 8.142E+02 },
		  { 7.000E-02 , 8.205E+02 },
		  { 7.500E-02 , 8.243E+02 },
		  { 8.000E-02 , 8.260E+02 },
		  { 8.500E-02 , 8.258E+02 },
		  { 9.000E-02 , 8.239E+02 },
		  { 9.500E-02 , 8.206E+02 },
		  { 1.000E-01 , 8.161E+02 },
		  { 1.250E-01 , 7.814E+02 },
		  { 1.500E-01 , 7.371E+02 },
		  { 1.750E-01 , 6.969E+02 },
		  { 2.000E-01 , 6.613E+02 },
		  { 2.250E-01 , 6.294E+02 },
		  { 2.500E-01 , 6.006E+02 },
		  { 2.750E-01 , 5.744E+02 },
		  { 3.000E-01 , 5.504E+02 },
		  { 3.500E-01 , 5.080E+02 },
		  { 4.000E-01 , 4.719E+02 },
		  { 4.500E-01 , 4.406E+02 },
		  { 5.000E-01 , 4.132E+02 },
		  { 5.500E-01 , 3.891E+02 },
		  { 6.000E-01 , 3.680E+02 },
		  { 6.500E-01 , 3.492E+02 },
		  { 7.000E-01 , 3.325E+02 },
		  { 7.500E-01 , 3.175E+02 },
		  { 8.000E-01 , 3.039E+02 },
		  { 8.500E-01 , 2.917E+02 },
		  { 9.000E-01 , 2.805E+02 },
		  { 9.500E-01 , 2.702E+02 },
		  { 1.000E+00 , 2.608E+02 },
		  { 1.250E+00 , 2.229E+02 },
		  { 1.500E+00 , 1.957E+02 },
		  { 1.750E+00 , 1.749E+02 },
		  { 2.000E+00 , 1.586E+02 },
		  { 2.250E+00 , 1.454E+02 },
		  { 2.500E+00 , 1.344E+02 },
		  { 2.750E+00 , 1.251E+02 },
		  { 3.000E+00 , 1.172E+02 },
		  { 3.500E+00 , 1.042E+02 },
		  { 4.000E+00 , 9.404E+01 },
		  { 4.500E+00 , 8.586E+01 },
		  { 5.000E+00 , 7.911E+01 },
		  { 5.500E+00 , 7.343E+01 },
		  { 6.000E+00 , 6.858E+01 },
		  { 6.500E+00 , 6.438E+01 },
		  { 7.000E+00 , 6.071E+01 },
		  { 7.500E+00 , 5.747E+01 },
		  { 8.000E+00 , 5.460E+01 },
		  { 8.500E+00 , 5.202E+01 },
		  { 9.000E+00 , 4.969E+01 },
		  { 9.500E+00 , 4.759E+01 },
		  { 1.000E+01 , 4.567E+01 },
		  { 1.250E+01 , 3.815E+01 },
		  { 1.500E+01 , 3.292E+01 },
		  { 1.750E+01 , 2.905E+01 },
		  { 2.000E+01 , 2.607E+01 },
		  { 2.500E+01 , 2.175E+01 },
		  { 2.750E+01 , 2.013E+01 },
		  { 3.000E+01 , 1.876E+01 },
		  { 3.500E+01 , 1.656E+01 },
		  { 4.000E+01 , 1.488E+01 },
		  { 4.500E+01 , 1.354E+01 },
		  { 5.000E+01 , 1.245E+01 },
		  { 5.500E+01 , 1.154E+01 },
		  { 6.000E+01 , 1.078E+01 },
		  { 6.500E+01 , 1.013E+01 },
		  { 7.000E+01 , 9.559E+00 },
		  { 7.500E+01 , 9.063E+00 },
		  { 8.000E+01 , 8.625E+00 },
		  { 8.500E+01 , 8.236E+00 },
		  { 9.000E+01 , 7.888E+00 },
		  { 9.500E+01 , 7.573E+00 },
		  { 1.000E+02 , 7.289E+00 },
		  { 1.250E+02 , 6.192E+00 },
		  { 1.500E+02 , 5.445E+00 },
		  { 1.750E+02 , 4.903E+00 },
		  { 2.000E+02 , 4.492E+00 },
		  { 2.250E+02 , 4.170E+00 },
		  { 2.500E+02 , 3.911E+00 },
		  { 2.750E+02 , 3.698E+00 },
		  { 3.000E+02 , 3.520E+00 },
		  { 3.500E+02 , 3.241E+00 },
		  { 4.000E+02 , 3.032E+00 },
		  { 4.500E+02 , 2.871E+00 },
		  { 5.000E+02 , 2.743E+00 },
		  { 5.500E+02 , 2.640E+00 },
		  { 6.000E+02 , 2.556E+00 },
		  { 6.500E+02 , 2.485E+00 },
		  { 7.000E+02 , 2.426E+00 },
		  { 7.500E+02 , 2.376E+00 },
		  { 8.000E+02 , 2.333E+00 },
		  { 8.500E+02 , 2.296E+00 },
		  { 9.000E+02 , 2.264E+00 },
		  { 9.500E+02 , 2.236E+00 },
		  { 1.000E+03 , 2.211E+00 },
		  { 1.500E+03 , 2.070E+00 },
		  { 2.000E+03 , 2.021E+00 },
		  { 2.500E+03 , 2.004E+00 },
		  { 3.000E+03 , 2.001E+00 },
		  { 4.000E+03 , 2.012E+00 },
		  { 5.000E+03 , 2.031E+00 },
		  { 6.000E+03 , 2.052E+00 },
		  { 7.000E+03 , 2.072E+00 },
		  { 8.000E+03 , 2.091E+00 },
		  { 9.000E+03 , 2.109E+00 },
		  { 1.000E+04 , 2.126E+00 }
  }
};


PSTAR_data_for_material_struct PSTAR_Aluminum_Oxide = {
  Aluminum_Oxide,
  PARTICLE_PROTON_NUMBER,
  {
		  { 1.000E-03 , 8.929E+01 },
		  { 1.500E-03 , 1.038E+02 },
		  { 2.000E-03 , 1.163E+02 },
		  { 2.500E-03 , 1.274E+02 },
		  { 3.000E-03 , 1.376E+02 },
		  { 4.000E-03 , 1.559E+02 },
		  { 5.000E-03 , 1.723E+02 },
		  { 6.000E-03 , 1.872E+02 },
		  { 7.000E-03 , 2.010E+02 },
		  { 8.000E-03 , 2.139E+02 },
		  { 9.000E-03 , 2.261E+02 },
		  { 1.000E-02 , 2.377E+02 },
		  { 1.250E-02 , 2.607E+02 },
		  { 1.500E-02 , 2.809E+02 },
		  { 1.750E-02 , 2.989E+02 },
		  { 2.000E-02 , 3.152E+02 },
		  { 2.250E-02 , 3.300E+02 },
		  { 2.500E-02 , 3.436E+02 },
		  { 2.750E-02 , 3.560E+02 },
		  { 3.000E-02 , 3.674E+02 },
		  { 3.500E-02 , 3.875E+02 },
		  { 4.000E-02 , 4.045E+02 },
		  { 4.500E-02 , 4.188E+02 },
		  { 5.000E-02 , 4.308E+02 },
		  { 5.500E-02 , 4.408E+02 },
		  { 6.000E-02 , 4.490E+02 },
		  { 6.500E-02 , 4.557E+02 },
		  { 7.000E-02 , 4.609E+02 },
		  { 7.500E-02 , 4.649E+02 },
		  { 8.000E-02 , 4.678E+02 },
		  { 8.500E-02 , 4.697E+02 },
		  { 9.000E-02 , 4.708E+02 },
		  { 9.500E-02 , 4.712E+02 },
		  { 1.000E-01 , 4.709E+02 },
		  { 1.250E-01 , 4.627E+02 },
		  { 1.500E-01 , 4.479E+02 },
		  { 1.750E-01 , 4.307E+02 },
		  { 2.000E-01 , 4.133E+02 },
		  { 2.250E-01 , 3.970E+02 },
		  { 2.500E-01 , 3.819E+02 },
		  { 2.750E-01 , 3.679E+02 },
		  { 3.000E-01 , 3.549E+02 },
		  { 3.500E-01 , 3.314E+02 },
		  { 4.000E-01 , 3.109E+02 },
		  { 4.500E-01 , 2.928E+02 },
		  { 5.000E-01 , 2.768E+02 },
		  { 5.500E-01 , 2.625E+02 },
		  { 6.000E-01 , 2.497E+02 },
		  { 6.500E-01 , 2.383E+02 },
		  { 7.000E-01 , 2.281E+02 },
		  { 7.500E-01 , 2.188E+02 },
		  { 8.000E-01 , 2.104E+02 },
		  { 8.500E-01 , 2.028E+02 },
		  { 9.000E-01 , 1.958E+02 },
		  { 9.500E-01 , 1.894E+02 },
		  { 1.000E+00 , 1.834E+02 },
		  { 1.250E+00 , 1.590E+02 },
		  { 1.500E+00 , 1.410E+02 },
		  { 1.750E+00 , 1.271E+02 },
		  { 2.000E+00 , 1.160E+02 },
		  { 2.250E+00 , 1.069E+02 },
		  { 2.500E+00 , 9.933E+01 },
		  { 2.750E+00 , 9.285E+01 },
		  { 3.000E+00 , 8.726E+01 },
		  { 3.500E+00 , 7.807E+01 },
		  { 4.000E+00 , 7.082E+01 },
		  { 4.500E+00 , 6.494E+01 },
		  { 5.000E+00 , 6.005E+01 },
		  { 5.500E+00 , 5.593E+01 },
		  { 6.000E+00 , 5.238E+01 },
		  { 6.500E+00 , 4.931E+01 },
		  { 7.000E+00 , 4.661E+01 },
		  { 7.500E+00 , 4.422E+01 },
		  { 8.000E+00 , 4.208E+01 },
		  { 8.500E+00 , 4.017E+01 },
		  { 9.000E+00 , 3.844E+01 },
		  { 9.500E+00 , 3.686E+01 },
		  { 1.000E+01 , 3.543E+01 },
		  { 1.250E+01 , 2.977E+01 },
		  { 1.500E+01 , 2.580E+01 },
		  { 1.750E+01 , 2.285E+01 },
		  { 2.000E+01 , 2.056E+01 },
		  { 2.500E+01 , 1.723E+01 },
		  { 2.750E+01 , 1.598E+01 },
		  { 3.000E+01 , 1.491E+01 },
		  { 3.500E+01 , 1.320E+01 },
		  { 4.000E+01 , 1.188E+01 },
		  { 4.500E+01 , 1.083E+01 },
		  { 5.000E+01 , 9.977E+00 },
		  { 5.500E+01 , 9.265E+00 },
		  { 6.000E+01 , 8.662E+00 },
		  { 6.500E+01 , 8.145E+00 },
		  { 7.000E+01 , 7.696E+00 },
		  { 7.500E+01 , 7.303E+00 },
		  { 8.000E+01 , 6.956E+00 },
		  { 8.500E+01 , 6.647E+00 },
		  { 9.000E+01 , 6.370E+00 },
		  { 9.500E+01 , 6.120E+00 },
		  { 1.000E+02 , 5.893E+00 },
		  { 1.250E+02 , 5.018E+00 },
		  { 1.500E+02 , 4.421E+00 },
		  { 1.750E+02 , 3.987E+00 },
		  { 2.000E+02 , 3.657E+00 },
		  { 2.250E+02 , 3.398E+00 },
		  { 2.500E+02 , 3.190E+00 },
		  { 2.750E+02 , 3.019E+00 },
		  { 3.000E+02 , 2.876E+00 },
		  { 3.500E+02 , 2.651E+00 },
		  { 4.000E+02 , 2.483E+00 },
		  { 4.500E+02 , 2.353E+00 },
		  { 5.000E+02 , 2.248E+00 },
		  { 5.500E+02 , 2.164E+00 },
		  { 6.000E+02 , 2.094E+00 },
		  { 6.500E+02 , 2.036E+00 },
		  { 7.000E+02 , 1.988E+00 },
		  { 7.500E+02 , 1.946E+00 },
		  { 8.000E+02 , 1.910E+00 },
		  { 8.500E+02 , 1.879E+00 },
		  { 9.000E+02 , 1.853E+00 },
		  { 9.500E+02 , 1.829E+00 },
		  { 1.000E+03 , 1.809E+00 },
		  { 1.500E+03 , 1.697E+00 },
		  { 2.000E+03 , 1.660E+00 },
		  { 2.500E+03 , 1.651E+00 },
		  { 3.000E+03 , 1.653E+00 },
		  { 4.000E+03 , 1.669E+00 },
		  { 5.000E+03 , 1.690E+00 },
		  { 6.000E+03 , 1.711E+00 },
		  { 7.000E+03 , 1.731E+00 },
		  { 8.000E+03 , 1.749E+00 },
		  { 9.000E+03 , 1.766E+00 },
		  { 1.000E+04 , 1.782E+00 }
  }
};


PSTAR_data_for_material_struct PSTAR_Aluminum = {
  Aluminum,
  PARTICLE_PROTON_NUMBER,
  {
		  { 1.000E-03 , 1.043E+02 },
		  { 1.500E-03 , 1.239E+02 },
		  { 2.000E-03 , 1.404E+02 },
		  { 2.500E-03 , 1.550E+02 },
		  { 3.000E-03 , 1.683E+02 },
		  { 4.000E-03 , 1.921E+02 },
		  { 5.000E-03 , 2.131E+02 },
		  { 6.000E-03 , 2.323E+02 },
		  { 7.000E-03 , 2.499E+02 },
		  { 8.000E-03 , 2.664E+02 },
		  { 9.000E-03 , 2.819E+02 },
		  { 1.000E-02 , 2.966E+02 },
		  { 1.250E-02 , 3.245E+02 },
		  { 1.500E-02 , 3.483E+02 },
		  { 1.750E-02 , 3.689E+02 },
		  { 2.000E-02 , 3.867E+02 },
		  { 2.250E-02 , 4.022E+02 },
		  { 2.500E-02 , 4.157E+02 },
		  { 2.750E-02 , 4.273E+02 },
		  { 3.000E-02 , 4.373E+02 },
		  { 3.500E-02 , 4.529E+02 },
		  { 4.000E-02 , 4.638E+02 },
		  { 4.500E-02 , 4.709E+02 },
		  { 5.000E-02 , 4.749E+02 },
		  { 5.500E-02 , 4.766E+02 },
		  { 6.000E-02 , 4.764E+02 },
		  { 6.500E-02 , 4.749E+02 },
		  { 7.000E-02 , 4.724E+02 },
		  { 7.500E-02 , 4.691E+02 },
		  { 8.000E-02 , 4.653E+02 },
		  { 8.500E-02 , 4.611E+02 },
		  { 9.000E-02 , 4.567E+02 },
		  { 9.500E-02 , 4.522E+02 },
		  { 1.000E-01 , 4.477E+02 },
		  { 1.250E-01 , 4.253E+02 },
		  { 1.500E-01 , 4.051E+02 },
		  { 1.750E-01 , 3.873E+02 },
		  { 2.000E-01 , 3.715E+02 },
		  { 2.250E-01 , 3.573E+02 },
		  { 2.500E-01 , 3.444E+02 },
		  { 2.750E-01 , 3.327E+02 },
		  { 3.000E-01 , 3.218E+02 },
		  { 3.500E-01 , 3.020E+02 },
		  { 4.000E-01 , 2.844E+02 },
		  { 4.500E-01 , 2.689E+02 },
		  { 5.000E-01 , 2.550E+02 },
		  { 5.500E-01 , 2.427E+02 },
		  { 6.000E-01 , 2.316E+02 },
		  { 6.500E-01 , 2.216E+02 },
		  { 7.000E-01 , 2.126E+02 },
		  { 7.500E-01 , 2.043E+02 },
		  { 8.000E-01 , 1.968E+02 },
		  { 8.500E-01 , 1.899E+02 },
		  { 9.000E-01 , 1.835E+02 },
		  { 9.500E-01 , 1.775E+02 },
		  { 1.000E+00 , 1.720E+02 },
		  { 1.250E+00 , 1.495E+02 },
		  { 1.500E+00 , 1.328E+02 },
		  { 1.750E+00 , 1.199E+02 },
		  { 2.000E+00 , 1.095E+02 },
		  { 2.250E+00 , 1.010E+02 },
		  { 2.500E+00 , 9.383E+01 },
		  { 2.750E+00 , 8.775E+01 },
		  { 3.000E+00 , 8.250E+01 },
		  { 3.500E+00 , 7.388E+01 },
		  { 4.000E+00 , 6.707E+01 },
		  { 4.500E+00 , 6.154E+01 },
		  { 5.000E+00 , 5.695E+01 },
		  { 5.500E+00 , 5.306E+01 },
		  { 6.000E+00 , 4.973E+01 },
		  { 6.500E+00 , 4.684E+01 },
		  { 7.000E+00 , 4.430E+01 },
		  { 7.500E+00 , 4.205E+01 },
		  { 8.000E+00 , 4.004E+01 },
		  { 8.500E+00 , 3.824E+01 },
		  { 9.000E+00 , 3.660E+01 },
		  { 9.500E+00 , 3.512E+01 },
		  { 1.000E+01 , 3.376E+01 },
		  { 1.250E+01 , 2.842E+01 },
		  { 1.500E+01 , 2.466E+01 },
		  { 1.750E+01 , 2.186E+01 },
		  { 2.000E+01 , 1.969E+01 },
		  { 2.500E+01 , 1.652E+01 },
		  { 2.750E+01 , 1.532E+01 },
		  { 3.000E+01 , 1.431E+01 },
		  { 3.500E+01 , 1.268E+01 },
		  { 4.000E+01 , 1.142E+01 },
		  { 4.500E+01 , 1.041E+01 },
		  { 5.000E+01 , 9.594E+00 },
		  { 5.500E+01 , 8.911E+00 },
		  { 6.000E+01 , 8.334E+00 },
		  { 6.500E+01 , 7.838E+00 },
		  { 7.000E+01 , 7.408E+00 },
		  { 7.500E+01 , 7.031E+00 },
		  { 8.000E+01 , 6.698E+00 },
		  { 8.500E+01 , 6.401E+00 },
		  { 9.000E+01 , 6.135E+00 },
		  { 9.500E+01 , 5.895E+00 },
		  { 1.000E+02 , 5.678E+00 },
		  { 1.250E+02 , 4.837E+00 },
		  { 1.500E+02 , 4.262E+00 },
		  { 1.750E+02 , 3.844E+00 },
		  { 2.000E+02 , 3.526E+00 },
		  { 2.250E+02 , 3.277E+00 },
		  { 2.500E+02 , 3.076E+00 },
		  { 2.750E+02 , 2.911E+00 },
		  { 3.000E+02 , 2.773E+00 },
		  { 3.500E+02 , 2.555E+00 },
		  { 4.000E+02 , 2.393E+00 },
		  { 4.500E+02 , 2.267E+00 },
		  { 5.000E+02 , 2.167E+00 },
		  { 5.500E+02 , 2.086E+00 },
		  { 6.000E+02 , 2.020E+00 },
		  { 6.500E+02 , 1.965E+00 },
		  { 7.000E+02 , 1.918E+00 },
		  { 7.500E+02 , 1.879E+00 },
		  { 8.000E+02 , 1.845E+00 },
		  { 8.500E+02 , 1.816E+00 },
		  { 9.000E+02 , 1.791E+00 },
		  { 9.500E+02 , 1.769E+00 },
		  { 1.000E+03 , 1.750E+00 },
		  { 1.500E+03 , 1.647E+00 },
		  { 2.000E+03 , 1.618E+00 },
		  { 2.500E+03 , 1.613E+00 },
		  { 3.000E+03 , 1.619E+00 },
		  { 4.000E+03 , 1.642E+00 },
		  { 5.000E+03 , 1.668E+00 },
		  { 6.000E+03 , 1.692E+00 },
		  { 7.000E+03 , 1.714E+00 },
		  { 8.000E+03 , 1.734E+00 },
		  { 9.000E+03 , 1.752E+00 },
		  { 1.000E+04 , 1.768E+00 }
  }
};


PSTAR_data_for_material_struct PSTAR_PMMA = {
  PMMA,
  PARTICLE_PROTON_NUMBER,
    {
		  { 0.001 , 214.7 },
		  { 0.0015 , 246.3 },
		  { 0.002 , 274.6 },
		  { 0.0025 , 300.4 },
		  { 0.003 , 324.2 },
		  { 0.004 , 363.5 },
		  { 0.005 , 399.4 },
		  { 0.006 , 432.2 },
		  { 0.007 , 462.4 },
		  { 0.008 , 489.9 },
		  { 0.009 , 515.3 },
		  { 0.01 , 539.1 },
		  { 0.0125 , 587 },
		  { 0.015 , 627.7 },
		  { 0.0175 , 663.2 },
		  { 0.02 , 694.8 },
		  { 0.0225 , 722.9 },
		  { 0.025 , 747.9 },
		  { 0.0275 , 770 },
		  { 0.03 , 789.8 },
		  { 0.035 , 824.4 },
		  { 0.04 , 853.7 },
		  { 0.045 , 877.9 },
		  { 0.05 , 897.2 },
		  { 0.055 , 911.8 },
		  { 0.06 , 922.4 },
		  { 0.065 , 929.6 },
		  { 0.07 , 934 },
		  { 0.075 , 935.8 },
		  { 0.08 , 935.5 },
		  { 0.085 , 933.4 },
		  { 0.09 , 929.6 },
		  { 0.095 , 924.5 },
		  { 0.1 , 918.3 },
		  { 0.125 , 875.7 },
		  { 0.15 , 824.3 },
		  { 0.175 , 772.3 },
		  { 0.2 , 723.2 },
		  { 0.225 , 676.9 },
		  { 0.25 , 634.6 },
		  { 0.275 , 596.9 },
		  { 0.3 , 563.4 },
		  { 0.35 , 507.7 },
		  { 0.4 , 463.9 },
		  { 0.45 , 428.9 },
		  { 0.5 , 400.6 },
		  { 0.55 , 377 },
		  { 0.6 , 356.4 },
		  { 0.65 , 338.3 },
		  { 0.7 , 322.2 },
		  { 0.75 , 307.8 },
		  { 0.8 , 294.8 },
		  { 0.85 , 283 },
		  { 0.9 , 272.2 },
		  { 0.95 , 262.3 },
		  { 1 , 253.2 },
		  { 1.25 , 216.8 },
		  { 1.5 , 190.5 },
		  { 1.75 , 170.5 },
		  { 2 , 154.6 },
		  { 2.25 , 141.8 },
		  { 2.5 , 131.1 },
		  { 2.75 , 122.1 },
		  { 3 , 114.3 },
		  { 3.5 , 101.7 },
		  { 4 , 91.79 },
		  { 4.5 , 83.79 },
		  { 5 , 77.19 },
		  { 5.5 , 71.64 },
		  { 6 , 66.9 },
		  { 6.5 , 62.8 },
		  { 7 , 59.21 },
		  { 7.5 , 56.05 },
		  { 8 , 53.24 },
		  { 8.5 , 50.73 },
		  { 9 , 48.45 },
		  { 9.5 , 46.4 },
		  { 10 , 44.52 },
		  { 12.5 , 37.19 },
		  { 15 , 32.08 },
		  { 17.5 , 28.31 },
		  { 20 , 25.39 },
		  { 25 , 21.18 },
		  { 27.5 , 19.61 },
		  { 30 , 18.27 },
		  { 35 , 16.13 },
		  { 40 , 14.49 },
		  { 45 , 13.18 },
		  { 50 , 12.12 },
		  { 55 , 11.24 },
		  { 60 , 10.5 },
		  { 65 , 9.858 },
		  { 70 , 9.306 },
		  { 75 , 8.823 },
		  { 80 , 8.397 },
		  { 85 , 8.018 },
		  { 90 , 7.678 },
		  { 95 , 7.372 },
		  { 100 , 7.095 },
		  { 125 , 6.027 },
		  { 150 , 5.3 },
		  { 175 , 4.772 },
		  { 200 , 4.372 },
		  { 225 , 4.058 },
		  { 250 , 3.806 },
		  { 275 , 3.599 },
		  { 300 , 3.426 },
		  { 350 , 3.154 },
		  { 400 , 2.951 },
		  { 450 , 2.794 },
		  { 500 , 2.67 },
		  { 550 , 2.569 },
		  { 600 , 2.487 },
		  { 650 , 2.418 },
		  { 700 , 2.361 },
		  { 750 , 2.312 },
		  { 800 , 2.269 },
		  { 850 , 2.232 },
		  { 900 , 2.199 },
		  { 950 , 2.17 },
		  { 1000 , 2.145 },
		  { 1500 , 2.004 },
		  { 2000 , 1.954 },
		  { 2500 , 1.937 },
		  { 3000 , 1.934 },
		  { 4000 , 1.945 },
		  { 5000 , 1.964 },
		  { 6000 , 1.985 },
		  { 7000 , 2.005 },
		  { 8000 , 2.024 },
		  { 9000 , 2.042 },
		  { 10000 , 2.059 }
  }
};


PSTAR_data_for_material_struct PSTAR_Alanine = {
  Alanine,
  PARTICLE_PROTON_NUMBER,
    {
		  { 0.001 , 209.5 },
		  { 0.0015 , 240.4 },
		  { 0.002 , 268 },
		  { 0.0025 , 293.2 },
		  { 0.003 , 316.5 },
		  { 0.004 , 356.1 },
		  { 0.005 , 392 },
		  { 0.006 , 424.7 },
		  { 0.007 , 455.1 },
		  { 0.008 , 483 },
		  { 0.009 , 508.8 },
		  { 0.01 , 533.3 },
		  { 0.0125 , 581.7 },
		  { 0.015 , 623.1 },
		  { 0.0175 , 659.5 },
		  { 0.02 , 691.7 },
		  { 0.0225 , 720.6 },
		  { 0.025 , 746.2 },
		  { 0.0275 , 769.1 },
		  { 0.03 , 789.6 },
		  { 0.035 , 825.2 },
		  { 0.04 , 854.8 },
		  { 0.045 , 879 },
		  { 0.05 , 898.1 },
		  { 0.055 , 912.6 },
		  { 0.06 , 923.1 },
		  { 0.065 , 930.3 },
		  { 0.07 , 934.5 },
		  { 0.075 , 936.3 },
		  { 0.08 , 935.9 },
		  { 0.085 , 933.6 },
		  { 0.09 , 929.7 },
		  { 0.095 , 924.6 },
		  { 0.1 , 918.3 },
		  { 0.125 , 875.3 },
		  { 0.15 , 823.7 },
		  { 0.175 , 771.5 },
		  { 0.2 , 722.4 },
		  { 0.225 , 677.3 },
		  { 0.25 , 636.9 },
		  { 0.275 , 601.1 },
		  { 0.3 , 569.4 },
		  { 0.35 , 517.2 },
		  { 0.4 , 475.4 },
		  { 0.45 , 441.2 },
		  { 0.5 , 412.3 },
		  { 0.55 , 387.5 },
		  { 0.6 , 365.9 },
		  { 0.65 , 346.9 },
		  { 0.7 , 330.1 },
		  { 0.75 , 315 },
		  { 0.8 , 301.5 },
		  { 0.85 , 289.2 },
		  { 0.9 , 278 },
		  { 0.95 , 267.7 },
		  { 1 , 258.4 },
		  { 1.25 , 220.7 },
		  { 1.5 , 193.7 },
		  { 1.75 , 173.1 },
		  { 2 , 157 },
		  { 2.25 , 143.8 },
		  { 2.5 , 133 },
		  { 2.75 , 123.7 },
		  { 3 , 115.8 },
		  { 3.5 , 103 },
		  { 4 , 92.89 },
		  { 4.5 , 84.78 },
		  { 5 , 78.08 },
		  { 5.5 , 72.45 },
		  { 6 , 67.64 },
		  { 6.5 , 63.48 },
		  { 7 , 59.85 },
		  { 7.5 , 56.64 },
		  { 8 , 53.79 },
		  { 8.5 , 51.25 },
		  { 9 , 48.95 },
		  { 9.5 , 46.87 },
		  { 10 , 44.96 },
		  { 12.5 , 37.55 },
		  { 15 , 32.38 },
		  { 17.5 , 28.56 },
		  { 20 , 25.62 },
		  { 25 , 21.36 },
		  { 27.5 , 19.77 },
		  { 30 , 18.42 },
		  { 35 , 16.26 },
		  { 40 , 14.6 },
		  { 45 , 13.28 },
		  { 50 , 12.21 },
		  { 55 , 11.32 },
		  { 60 , 10.57 },
		  { 65 , 9.929 },
		  { 70 , 9.372 },
		  { 75 , 8.886 },
		  { 80 , 8.455 },
		  { 85 , 8.073 },
		  { 90 , 7.73 },
		  { 95 , 7.422 },
		  { 100 , 7.142 },
		  { 125 , 6.065 },
		  { 150 , 5.331 },
		  { 175 , 4.8 },
		  { 200 , 4.396 },
		  { 225 , 4.08 },
		  { 250 , 3.825 },
		  { 275 , 3.616 },
		  { 300 , 3.441 },
		  { 350 , 3.167 },
		  { 400 , 2.961 },
		  { 450 , 2.802 },
		  { 500 , 2.677 },
		  { 550 , 2.575 },
		  { 600 , 2.491 },
		  { 650 , 2.421 },
		  { 700 , 2.362 },
		  { 750 , 2.313 },
		  { 800 , 2.27 },
		  { 850 , 2.233 },
		  { 900 , 2.2 },
		  { 950 , 2.173 },
		  { 1000 , 2.148 },
		  { 1500 , 2.016 },
		  { 2000 , 1.976 },
		  { 2500 , 1.968 },
		  { 3000 , 1.973 },
		  { 4000 , 2 },
		  { 5000 , 2.032 },
		  { 6000 , 2.064 },
		  { 7000 , 2.094 },
		  { 8000 , 2.122 },
		  { 9000 , 2.149 },
		  { 10000 , 2.173 }
  }
};


PSTAR_data_for_material_struct PSTAR_LiF = {
  LiF,
  PARTICLE_PROTON_NUMBER,
    {
		  { 1.000E-03 , 1.008E+02 },
		  { 1.500E-03 , 1.157E+02 },
		  { 2.000E-03 , 1.289E+02 },
		  { 2.500E-03 , 1.408E+02 },
		  { 3.000E-03 , 1.518E+02 },
		  { 4.000E-03 , 1.717E+02 },
		  { 5.000E-03 , 1.895E+02 },
		  { 6.000E-03 , 2.058E+02 },
		  { 7.000E-03 , 2.210E+02 },
		  { 8.000E-03 , 2.352E+02 },
		  { 9.000E-03 , 2.485E+02 },
		  { 1.000E-02 , 2.613E+02 },
		  { 1.250E-02 , 2.866E+02 },
		  { 1.500E-02 , 3.090E+02 },
		  { 1.750E-02 , 3.291E+02 },
		  { 2.000E-02 , 3.474E+02 },
		  { 2.250E-02 , 3.640E+02 },
		  { 2.500E-02 , 3.793E+02 },
		  { 2.750E-02 , 3.934E+02 },
		  { 3.000E-02 , 4.065E+02 },
		  { 3.500E-02 , 4.298E+02 },
		  { 4.000E-02 , 4.498E+02 },
		  { 4.500E-02 , 4.671E+02 },
		  { 5.000E-02 , 4.820E+02 },
		  { 5.500E-02 , 4.947E+02 },
		  { 6.000E-02 , 5.055E+02 },
		  { 6.500E-02 , 5.147E+02 },
		  { 7.000E-02 , 5.223E+02 },
		  { 7.500E-02 , 5.286E+02 },
		  { 8.000E-02 , 5.337E+02 },
		  { 8.500E-02 , 5.376E+02 },
		  { 9.000E-02 , 5.406E+02 },
		  { 9.500E-02 , 5.427E+02 },
		  { 1.000E-01 , 5.440E+02 },
		  { 1.250E-01 , 5.411E+02 },
		  { 1.500E-01 , 5.281E+02 },
		  { 1.750E-01 , 5.098E+02 },
		  { 2.000E-01 , 4.893E+02 },
		  { 2.250E-01 , 4.679E+02 },
		  { 2.500E-01 , 4.469E+02 },
		  { 2.750E-01 , 4.273E+02 },
		  { 3.000E-01 , 4.091E+02 },
		  { 3.500E-01 , 3.773E+02 },
		  { 4.000E-01 , 3.507E+02 },
		  { 4.500E-01 , 3.283E+02 },
		  { 5.000E-01 , 3.093E+02 },
		  { 5.500E-01 , 2.930E+02 },
		  { 6.000E-01 , 2.783E+02 },
		  { 6.500E-01 , 2.652E+02 },
		  { 7.000E-01 , 2.534E+02 },
		  { 7.500E-01 , 2.427E+02 },
		  { 8.000E-01 , 2.329E+02 },
		  { 8.500E-01 , 2.240E+02 },
		  { 9.000E-01 , 2.158E+02 },
		  { 9.500E-01 , 2.083E+02 },
		  { 1.000E+00 , 2.014E+02 },
		  { 1.250E+00 , 1.732E+02 },
		  { 1.500E+00 , 1.526E+02 },
		  { 1.750E+00 , 1.369E+02 },
		  { 2.000E+00 , 1.244E+02 },
		  { 2.250E+00 , 1.142E+02 },
		  { 2.500E+00 , 1.058E+02 },
		  { 2.750E+00 , 9.859E+01 },
		  { 3.000E+00 , 9.243E+01 },
		  { 3.500E+00 , 8.237E+01 },
		  { 4.000E+00 , 7.447E+01 },
		  { 4.500E+00 , 6.807E+01 },
		  { 5.000E+00 , 6.279E+01 },
		  { 5.500E+00 , 5.834E+01 },
		  { 6.000E+00 , 5.453E+01 },
		  { 6.500E+00 , 5.124E+01 },
		  { 7.000E+00 , 4.836E+01 },
		  { 7.500E+00 , 4.581E+01 },
		  { 8.000E+00 , 4.354E+01 },
		  { 8.500E+00 , 4.151E+01 },
		  { 9.000E+00 , 3.967E+01 },
		  { 9.500E+00 , 3.801E+01 },
		  { 1.000E+01 , 3.649E+01 },
		  { 1.250E+01 , 3.054E+01 },
		  { 1.500E+01 , 2.639E+01 },
		  { 1.750E+01 , 2.331E+01 },
		  { 2.000E+01 , 2.093E+01 },
		  { 2.500E+01 , 1.749E+01 },
		  { 2.750E+01 , 1.620E+01 },
		  { 3.000E+01 , 1.510E+01 },
		  { 3.500E+01 , 1.334E+01 },
		  { 4.000E+01 , 1.199E+01 },
		  { 4.500E+01 , 1.092E+01 },
		  { 5.000E+01 , 1.005E+01 },
		  { 5.500E+01 , 9.320E+00 },
		  { 6.000E+01 , 8.707E+00 },
		  { 6.500E+01 , 8.181E+00 },
		  { 7.000E+01 , 7.725E+00 },
		  { 7.500E+01 , 7.327E+00 },
		  { 8.000E+01 , 6.975E+00 },
		  { 8.500E+01 , 6.661E+00 },
		  { 9.000E+01 , 6.381E+00 },
		  { 9.500E+01 , 6.128E+00 },
		  { 1.000E+02 , 5.899E+00 },
		  { 1.250E+02 , 5.015E+00 },
		  { 1.500E+02 , 4.412E+00 },
		  { 1.750E+02 , 3.975E+00 },
		  { 2.000E+02 , 3.643E+00 },
		  { 2.250E+02 , 3.383E+00 },
		  { 2.500E+02 , 3.174E+00 },
		  { 2.750E+02 , 3.002E+00 },
		  { 3.000E+02 , 2.858E+00 },
		  { 3.500E+02 , 2.633E+00 },
		  { 4.000E+02 , 2.464E+00 },
		  { 4.500E+02 , 2.333E+00 },
		  { 5.000E+02 , 2.229E+00 },
		  { 5.500E+02 , 2.144E+00 },
		  { 6.000E+02 , 2.075E+00 },
		  { 6.500E+02 , 2.017E+00 },
		  { 7.000E+02 , 1.968E+00 },
		  { 7.500E+02 , 1.927E+00 },
		  { 8.000E+02 , 1.891E+00 },
		  { 8.500E+02 , 1.860E+00 },
		  { 9.000E+02 , 1.833E+00 },
		  { 9.500E+02 , 1.810E+00 },
		  { 1.000E+03 , 1.789E+00 },
		  { 1.500E+03 , 1.675E+00 },
		  { 2.000E+03 , 1.635E+00 },
		  { 2.500E+03 , 1.622E+00 },
		  { 3.000E+03 , 1.621E+00 },
		  { 4.000E+03 , 1.631E+00 },
		  { 5.000E+03 , 1.648E+00 },
		  { 6.000E+03 , 1.665E+00 },
		  { 7.000E+03 , 1.682E+00 },
		  { 8.000E+03 , 1.697E+00 },
		  { 9.000E+03 , 1.712E+00 },
		  { 1.000E+04 , 1.726E+00 }
  }
};


PSTAR_data_for_material_struct PSTAR_Air = {
  Air,
  PARTICLE_PROTON_NUMBER,
    {
		  { 1.000E-03 , 1.414E+02 },
		  { 1.500E-03 , 1.651E+02 },
		  { 2.000E-03 , 1.855E+02 },
		  { 2.500E-03 , 2.038E+02 },
		  { 3.000E-03 , 2.206E+02 },
		  { 4.000E-03 , 2.507E+02 },
		  { 5.000E-03 , 2.776E+02 },
		  { 6.000E-03 , 3.021E+02 },
		  { 7.000E-03 , 3.248E+02 },
		  { 8.000E-03 , 3.460E+02 },
		  { 9.000E-03 , 3.660E+02 },
		  { 1.000E-02 , 3.850E+02 },
		  { 1.250E-02 , 4.224E+02 },
		  { 1.500E-02 , 4.552E+02 },
		  { 1.750E-02 , 4.843E+02 },
		  { 2.000E-02 , 5.106E+02 },
		  { 2.250E-02 , 5.343E+02 },
		  { 2.500E-02 , 5.558E+02 },
		  { 2.750E-02 , 5.755E+02 },
		  { 3.000E-02 , 5.934E+02 },
		  { 3.500E-02 , 6.246E+02 },
		  { 4.000E-02 , 6.506E+02 },
		  { 4.500E-02 , 6.721E+02 },
		  { 5.000E-02 , 6.897E+02 },
		  { 5.500E-02 , 7.038E+02 },
		  { 6.000E-02 , 7.149E+02 },
		  { 6.500E-02 , 7.233E+02 },
		  { 7.000E-02 , 7.293E+02 },
		  { 7.500E-02 , 7.333E+02 },
		  { 8.000E-02 , 7.355E+02 },
		  { 8.500E-02 , 7.360E+02 },
		  { 9.000E-02 , 7.352E+02 },
		  { 9.500E-02 , 7.332E+02 },
		  { 1.000E-01 , 7.301E+02 },
		  { 1.250E-01 , 7.038E+02 },
		  { 1.500E-01 , 6.680E+02 },
		  { 1.750E-01 , 6.298E+02 },
		  { 2.000E-01 , 5.928E+02 },
		  { 2.250E-01 , 5.589E+02 },
		  { 2.500E-01 , 5.284E+02 },
		  { 2.750E-01 , 5.011E+02 },
		  { 3.000E-01 , 4.767E+02 },
		  { 3.500E-01 , 4.353E+02 },
		  { 4.000E-01 , 4.015E+02 },
		  { 4.500E-01 , 3.736E+02 },
		  { 5.000E-01 , 3.501E+02 },
		  { 5.500E-01 , 3.300E+02 },
		  { 6.000E-01 , 3.123E+02 },
		  { 6.500E-01 , 2.967E+02 },
		  { 7.000E-01 , 2.826E+02 },
		  { 7.500E-01 , 2.701E+02 },
		  { 8.000E-01 , 2.589E+02 },
		  { 8.500E-01 , 2.486E+02 },
		  { 9.000E-01 , 2.393E+02 },
		  { 9.500E-01 , 2.308E+02 },
		  { 1.000E+00 , 2.229E+02 },
		  { 1.250E+00 , 1.912E+02 },
		  { 1.500E+00 , 1.683E+02 },
		  { 1.750E+00 , 1.509E+02 },
		  { 2.000E+00 , 1.371E+02 },
		  { 2.250E+00 , 1.258E+02 },
		  { 2.500E+00 , 1.165E+02 },
		  { 2.750E+00 , 1.086E+02 },
		  { 3.000E+00 , 1.018E+02 },
		  { 3.500E+00 , 9.068E+01 },
		  { 4.000E+00 , 8.197E+01 },
		  { 4.500E+00 , 7.492E+01 },
		  { 5.000E+00 , 6.909E+01 },
		  { 5.500E+00 , 6.417E+01 },
		  { 6.000E+00 , 5.997E+01 },
		  { 6.500E+00 , 5.633E+01 },
		  { 7.000E+00 , 5.315E+01 },
		  { 7.500E+00 , 5.033E+01 },
		  { 8.000E+00 , 4.783E+01 },
		  { 8.500E+00 , 4.559E+01 },
		  { 9.000E+00 , 4.357E+01 },
		  { 9.500E+00 , 4.173E+01 },
		  { 1.000E+01 , 4.006E+01 },
		  { 1.250E+01 , 3.351E+01 },
		  { 1.500E+01 , 2.894E+01 },
		  { 1.750E+01 , 2.555E+01 },
		  { 2.000E+01 , 2.294E+01 },
		  { 2.500E+01 , 1.915E+01 },
		  { 2.750E+01 , 1.773E+01 },
		  { 3.000E+01 , 1.653E+01 },
		  { 3.500E+01 , 1.460E+01 },
		  { 4.000E+01 , 1.312E+01 },
		  { 4.500E+01 , 1.194E+01 },
		  { 5.000E+01 , 1.099E+01 },
		  { 5.500E+01 , 1.019E+01 },
		  { 6.000E+01 , 9.517E+00 },
		  { 6.500E+01 , 8.942E+00 },
		  { 7.000E+01 , 8.443E+00 },
		  { 7.500E+01 , 8.006E+00 },
		  { 8.000E+01 , 7.620E+00 },
		  { 8.500E+01 , 7.277E+00 },
		  { 9.000E+01 , 6.970E+00 },
		  { 9.500E+01 , 6.693E+00 },
		  { 1.000E+02 , 6.443E+00 },
		  { 1.250E+02 , 5.475E+00 },
		  { 1.500E+02 , 4.816E+00 },
		  { 1.750E+02 , 4.338E+00 },
		  { 2.000E+02 , 3.976E+00 },
		  { 2.250E+02 , 3.691E+00 },
		  { 2.500E+02 , 3.462E+00 },
		  { 2.750E+02 , 3.275E+00 },
		  { 3.000E+02 , 3.118E+00 },
		  { 3.500E+02 , 2.871E+00 },
		  { 4.000E+02 , 2.687E+00 },
		  { 4.500E+02 , 2.544E+00 },
		  { 5.000E+02 , 2.431E+00 },
		  { 5.500E+02 , 2.340E+00 },
		  { 6.000E+02 , 2.266E+00 },
		  { 6.500E+02 , 2.203E+00 },
		  { 7.000E+02 , 2.151E+00 },
		  { 7.500E+02 , 2.107E+00 },
		  { 8.000E+02 , 2.069E+00 },
		  { 8.500E+02 , 2.037E+00 },
		  { 9.000E+02 , 2.008E+00 },
		  { 9.500E+02 , 1.984E+00 },
		  { 1.000E+03 , 1.963E+00 },
		  { 1.500E+03 , 1.850E+00 },
		  { 2.000E+03 , 1.820E+00 },
		  { 2.500E+03 , 1.818E+00 },
		  { 3.000E+03 , 1.828E+00 },
		  { 4.000E+03 , 1.861E+00 },
		  { 5.000E+03 , 1.898E+00 },
		  { 6.000E+03 , 1.934E+00 },
		  { 7.000E+03 , 1.967E+00 },
		  { 8.000E+03 , 1.998E+00 },
		  { 9.000E+03 , 2.026E+00 },
		  { 1.000E+04 , 2.052E+00 }
  }
};

PSTAR_data_for_material_struct PSTAR_Silicon = {
  Silicon,
  PARTICLE_PROTON_NUMBER,
    {
		  { 1.000e-03 , 1.169e+02 },
		  { 1.500e-03 , 1.393e+02 },
		  { 2.000e-03 , 1.583e+02 },
		  { 2.500e-03 , 1.750e+02 },
		  { 3.000e-03 , 1.903e+02 },
		  { 4.000e-03 , 2.174e+02 },
		  { 5.000e-03 , 2.414e+02 },
		  { 6.000e-03 , 2.633e+02 },
		  { 7.000e-03 , 2.834e+02 },
		  { 8.000e-03 , 3.022e+02 },
		  { 9.000e-03 , 3.199e+02 },
		  { 1.000e-02 , 3.366e+02 },
		  { 1.250e-02 , 3.686e+02 },
		  { 1.500e-02 , 3.961e+02 },
		  { 1.750e-02 , 4.199e+02 },
		  { 2.000e-02 , 4.408e+02 },
		  { 2.250e-02 , 4.591e+02 },
		  { 2.500e-02 , 4.751e+02 },
		  { 2.750e-02 , 4.890e+02 },
		  { 3.000e-02 , 5.011e+02 },
		  { 3.500e-02 , 5.204e+02 },
		  { 4.000e-02 , 5.342e+02 },
		  { 4.500e-02 , 5.433e+02 },
		  { 5.000e-02 , 5.485e+02 },
		  { 5.500e-02 , 5.507e+02 },
		  { 6.000e-02 , 5.504e+02 },
		  { 6.500e-02 , 5.480e+02 },
		  { 7.000e-02 , 5.442e+02 },
		  { 7.500e-02 , 5.392e+02 },
		  { 8.000e-02 , 5.333e+02 },
		  { 8.500e-02 , 5.267e+02 },
		  { 9.000e-02 , 5.198e+02 },
		  { 9.500e-02 , 5.126e+02 },
		  { 1.000e-01 , 5.053e+02 },
		  { 1.250e-01 , 4.695e+02 },
		  { 1.500e-01 , 4.379e+02 },
		  { 1.750e-01 , 4.113e+02 },
		  { 2.000e-01 , 3.889e+02 },
		  { 2.250e-01 , 3.699e+02 },
		  { 2.500e-01 , 3.535e+02 },
		  { 2.750e-01 , 3.391e+02 },
		  { 3.000e-01 , 3.263e+02 },
		  { 3.500e-01 , 3.045e+02 },
		  { 4.000e-01 , 2.862e+02 },
		  { 4.500e-01 , 2.706e+02 },
		  { 5.000e-01 , 2.569e+02 },
		  { 5.500e-01 , 2.454e+02 },
		  { 6.000e-01 , 2.353e+02 },
		  { 6.500e-01 , 2.261e+02 },
		  { 7.000e-01 , 2.174e+02 },
		  { 7.500e-01 , 2.091e+02 },
		  { 8.000e-01 , 2.012e+02 },
		  { 8.500e-01 , 1.938e+02 },
		  { 9.000e-01 , 1.872e+02 },
		  { 9.500e-01 , 1.811e+02 },
		  { 1.000e+00 , 1.754e+02 },
		  { 1.250e+00 , 1.524e+02 },
		  { 1.500e+00 , 1.355e+02 },
		  { 1.750e+00 , 1.223e+02 },
		  { 2.000e+00 , 1.118e+02 },
		  { 2.250e+00 , 1.031e+02 },
		  { 2.500e+00 , 9.586e+01 },
		  { 2.750e+00 , 8.968e+01 },
		  { 3.000e+00 , 8.433e+01 },
		  { 3.500e+00 , 7.554e+01 },
		  { 4.000e+00 , 6.860e+01 },
		  { 4.500e+00 , 6.296e+01 },
		  { 5.000e+00 , 5.828e+01 },
		  { 5.500e+00 , 5.431e+01 },
		  { 6.000e+00 , 5.091e+01 },
		  { 6.500e+00 , 4.795e+01 },
		  { 7.000e+00 , 4.536e+01 },
		  { 7.500e+00 , 4.306e+01 },
		  { 8.000e+00 , 4.101e+01 },
		  { 8.500e+00 , 3.916e+01 },
		  { 9.000e+00 , 3.750e+01 },
		  { 9.500e+00 , 3.598e+01 },
		  { 1.000e+01 , 3.459e+01 },
		  { 1.250e+01 , 2.913e+01 },
		  { 1.500e+01 , 2.529e+01 },
		  { 1.750e+01 , 2.243e+01 },
		  { 2.000e+01 , 2.020e+01 },
		  { 2.500e+01 , 1.695e+01 },
		  { 2.750e+01 , 1.573e+01 },
		  { 3.000e+01 , 1.469e+01 },
		  { 3.500e+01 , 1.302e+01 },
		  { 4.000e+01 , 1.173e+01 },
		  { 4.500e+01 , 1.070e+01 },
		  { 5.000e+01 , 9.856e+00 },
		  { 5.500e+01 , 9.157e+00 },
		  { 6.000e+01 , 8.564e+00 },
		  { 6.500e+01 , 8.056e+00 },
		  { 7.000e+01 , 7.614e+00 },
		  { 7.500e+01 , 7.227e+00 },
		  { 8.000e+01 , 6.885e+00 },
		  { 8.500e+01 , 6.581e+00 },
		  { 9.000e+01 , 6.308e+00 },
		  { 9.500e+01 , 6.061e+00 },
		  { 1.000e+02 , 5.838e+00 },
		  { 1.250e+02 , 4.974e+00 },
		  { 1.500e+02 , 4.383e+00 },
		  { 1.750e+02 , 3.954e+00 },
		  { 2.000e+02 , 3.628e+00 },
		  { 2.250e+02 , 3.371e+00 },
		  { 2.500e+02 , 3.165e+00 },
		  { 2.750e+02 , 2.995e+00 },
		  { 3.000e+02 , 2.853e+00 },
		  { 3.500e+02 , 2.630e+00 },
		  { 4.000e+02 , 2.462e+00 },
		  { 4.500e+02 , 2.333e+00 },
		  { 5.000e+02 , 2.230e+00 },
		  { 5.500e+02 , 2.147e+00 },
		  { 6.000e+02 , 2.079e+00 },
		  { 6.500e+02 , 2.022e+00 },
		  { 7.000e+02 , 1.975e+00 },
		  { 7.500e+02 , 1.934e+00 },
		  { 8.000e+02 , 1.899e+00 },
		  { 8.500e+02 , 1.870e+00 },
		  { 9.000e+02 , 1.844e+00 },
		  { 9.500e+02 , 1.821e+00 },
		  { 1.000e+03 , 1.801e+00 },
		  { 1.500e+03 , 1.696e+00 },
		  { 2.000e+03 , 1.666e+00 },
		  { 2.500e+03 , 1.661e+00 },
		  { 3.000e+03 , 1.668e+00 },
		  { 4.000e+03 , 1.692e+00 },
		  { 5.000e+03 , 1.720e+00 },
		  { 6.000e+03 , 1.746e+00 },
		  { 7.000e+03 , 1.770e+00 },
		  { 8.000e+03 , 1.792e+00 },
		  { 9.000e+03 , 1.812e+00 },
		  { 1.000e+04 , 1.830e+00 }
  }
};

PSTAR_data_for_material_struct
PSTAR_Copper = {
  Copper,
  PARTICLE_PROTON_NUMBER,
    {
		  { 1.000e-03 , 3.931e+01 },
		  { 1.500e-03 , 4.697e+01 },
		  { 2.000e-03 , 5.340e+01 },
		  { 2.500e-03 , 5.906e+01 },
		  { 3.000e-03 , 6.416e+01 },
		  { 4.000e-03 , 7.324e+01 },
		  { 5.000e-03 , 8.124e+01 },
		  { 6.000e-03 , 8.849e+01 },
		  { 7.000e-03 , 9.517e+01 },
		  { 8.000e-03 , 1.014e+02 },
		  { 9.000e-03 , 1.073e+02 },
		  { 1.000e-02 , 1.128e+02 },
		  { 1.250e-02 , 1.236e+02 },
		  { 1.500e-02 , 1.329e+02 },
		  { 1.750e-02 , 1.411e+02 },
		  { 2.000e-02 , 1.484e+02 },
		  { 2.250e-02 , 1.548e+02 },
		  { 2.500e-02 , 1.606e+02 },
		  { 2.750e-02 , 1.657e+02 },
		  { 3.000e-02 , 1.703e+02 },
		  { 3.500e-02 , 1.781e+02 },
		  { 4.000e-02 , 1.844e+02 },
		  { 4.500e-02 , 1.894e+02 },
		  { 5.000e-02 , 1.935e+02 },
		  { 5.500e-02 , 1.968e+02 },
		  { 6.000e-02 , 1.996e+02 },
		  { 6.500e-02 , 2.018e+02 },
		  { 7.000e-02 , 2.036e+02 },
		  { 7.500e-02 , 2.051e+02 },
		  { 8.000e-02 , 2.063e+02 },
		  { 8.500e-02 , 2.073e+02 },
		  { 9.000e-02 , 2.082e+02 },
		  { 9.500e-02 , 2.088e+02 },
		  { 1.000e-01 , 2.093e+02 },
		  { 1.250e-01 , 2.104e+02 },
		  { 1.500e-01 , 2.097e+02 },
		  { 1.750e-01 , 2.079e+02 },
		  { 2.000e-01 , 2.055e+02 },
		  { 2.250e-01 , 2.026e+02 },
		  { 2.500e-01 , 1.994e+02 },
		  { 2.750e-01 , 1.961e+02 },
		  { 3.000e-01 , 1.926e+02 },
		  { 3.500e-01 , 1.856e+02 },
		  { 4.000e-01 , 1.788e+02 },
		  { 4.500e-01 , 1.722e+02 },
		  { 5.000e-01 , 1.660e+02 },
		  { 5.500e-01 , 1.598e+02 },
		  { 6.000e-01 , 1.538e+02 },
		  { 6.500e-01 , 1.481e+02 },
		  { 7.000e-01 , 1.428e+02 },
		  { 7.500e-01 , 1.379e+02 },
		  { 8.000e-01 , 1.334e+02 },
		  { 8.500e-01 , 1.292e+02 },
		  { 9.000e-01 , 1.253e+02 },
		  { 9.500e-01 , 1.218e+02 },
		  { 1.000e+00 , 1.184e+02 },
		  { 1.250e+00 , 1.048e+02 },
		  { 1.500e+00 , 9.450e+01 },
		  { 1.750e+00 , 8.652e+01 },
		  { 2.000e+00 , 7.992e+01 },
		  { 2.250e+00 , 7.430e+01 },
		  { 2.500e+00 , 6.960e+01 },
		  { 2.750e+00 , 6.556e+01 },
		  { 3.000e+00 , 6.199e+01 },
		  { 3.500e+00 , 5.610e+01 },
		  { 4.000e+00 , 5.136e+01 },
		  { 4.500e+00 , 4.746e+01 },
		  { 5.000e+00 , 4.418e+01 },
		  { 5.500e+00 , 4.139e+01 },
		  { 6.000e+00 , 3.897e+01 },
		  { 6.500e+00 , 3.685e+01 },
		  { 7.000e+00 , 3.498e+01 },
		  { 7.500e+00 , 3.331e+01 },
		  { 8.000e+00 , 3.181e+01 },
		  { 8.500e+00 , 3.046e+01 },
		  { 9.000e+00 , 2.924e+01 },
		  { 9.500e+00 , 2.812e+01 },
		  { 1.000e+01 , 2.709e+01 },
		  { 1.250e+01 , 2.301e+01 },
		  { 1.500e+01 , 2.010e+01 },
		  { 1.750e+01 , 1.791e+01 },
		  { 2.000e+01 , 1.620e+01 },
		  { 2.500e+01 , 1.368e+01 },
		  { 2.750e+01 , 1.273e+01 },
		  { 3.000e+01 , 1.191e+01 },
		  { 3.500e+01 , 1.060e+01 },
		  { 4.000e+01 , 9.577e+00 },
		  { 4.500e+01 , 8.760e+00 },
		  { 5.000e+01 , 8.090e+00 },
		  { 5.500e+01 , 7.530e+00 },
		  { 6.000e+01 , 7.055e+00 },
		  { 6.500e+01 , 6.646e+00 },
		  { 7.000e+01 , 6.291e+00 },
		  { 7.500e+01 , 5.979e+00 },
		  { 8.000e+01 , 5.702e+00 },
		  { 8.500e+01 , 5.455e+00 },
		  { 9.000e+01 , 5.234e+00 },
		  { 9.500e+01 , 5.034e+00 },
		  { 1.000e+02 , 4.852e+00 },
		  { 1.250e+02 , 4.147e+00 },
		  { 1.500e+02 , 3.664e+00 },
		  { 1.750e+02 , 3.311e+00 },
		  { 2.000e+02 , 3.042e+00 },
		  { 2.250e+02 , 2.830e+00 },
		  { 2.500e+02 , 2.659e+00 },
		  { 2.750e+02 , 2.518e+00 },
		  { 3.000e+02 , 2.400e+00 },
		  { 3.500e+02 , 2.214e+00 },
		  { 4.000e+02 , 2.074e+00 },
		  { 4.500e+02 , 1.966e+00 },
		  { 5.000e+02 , 1.880e+00 },
		  { 5.500e+02 , 1.811e+00 },
		  { 6.000e+02 , 1.754e+00 },
		  { 6.500e+02 , 1.706e+00 },
		  { 7.000e+02 , 1.666e+00 },
		  { 7.500e+02 , 1.632e+00 },
		  { 8.000e+02 , 1.603e+00 },
		  { 8.500e+02 , 1.578e+00 },
		  { 9.000e+02 , 1.556e+00 },
		  { 9.500e+02 , 1.538e+00 },
		  { 1.000e+03 , 1.521e+00 },
		  { 1.500e+03 , 1.433e+00 },
		  { 2.000e+03 , 1.407e+00 },
		  { 2.500e+03 , 1.404e+00 },
		  { 3.000e+03 , 1.409e+00 },
		  { 4.000e+03 , 1.430e+00 },
		  { 5.000e+03 , 1.454e+00 },
		  { 6.000e+03 , 1.476e+00 },
		  { 7.000e+03 , 1.498e+00 },
		  { 8.000e+03 , 1.517e+00 },
		  { 9.000e+03 , 1.535e+00 },
		  { 1.000e+04 , 1.552e+00 }
  }
};


PSTAR_data_struct PSTAR_data =
		{
				{ 		User_Defined_Material,
						Water_Liquid,
						Aluminum_Oxide,
						Aluminum,
						PMMA,
						Alanine,
						LiF,
						Air,
						Silicon,
						Copper },
				{ 		NULL,
						&PSTAR_Water,
						&PSTAR_Aluminum_Oxide,
						&PSTAR_Aluminum,
						&PSTAR_PMMA,
						&PSTAR_Alanine,
						&PSTAR_LiF,
						&PSTAR_Air,
						&PSTAR_Silicon,
						&PSTAR_Copper } };


int AT_PSTAR_wrapper( const long n,
		const double E_MeV_u[],
		const long particle_no[],
		const long material_no,
		const char info[],
		double mass_stopping_power_MeV_cm2_g[]){

	const PSTAR_data_for_material_struct * source_for_given_material = PSTAR_data.stopping_power_source_data[material_no];

	if( source_for_given_material == NULL ){
		char material_name[MATERIAL_NAME_LENGTH];
		AT_material_name_from_number(material_no,material_name);
#ifndef NDEBUG
		printf("Missing data for material [%s] in PSTAR data.\n", material_name);
#endif
		return AT_No_PSTAR_Data;
	}

	assert( source_for_given_material != NULL );

	const long n_data = N_PSTAR_DATAPOINTS;

	long i;
	for(i = 0; i < n; i++){
			mass_stopping_power_MeV_cm2_g[i] = AT_get_interpolated_y_from_input_2d_table(
					source_for_given_material->energy_and_stopping_power,
					n_data,
					E_MeV_u[i]);
			if( particle_no[i] != PARTICLE_PROTON_NUMBER){
				double Zeff_ion    =  AT_effective_charge_from_E_MeV_u_single(E_MeV_u[i], particle_no[i]);
				double Zeff_proton =  AT_effective_charge_from_E_MeV_u_single(E_MeV_u[i], PARTICLE_PROTON_NUMBER);
				mass_stopping_power_MeV_cm2_g[i] *= gsl_pow_2(Zeff_ion / Zeff_proton);
			}
		}
	return AT_Success;
}

